*****************************************************************
*** 
*** e-Stat project (BHPS  data) Stata syntax file
*** Version January  2013
*** Pierre Walthery & IAN Plewis -- CCSR/University of Manchester
*** 
*** Using BHPS original datasets from ESDS, this do file enables 
*** users to create two cohorts of children based on collated
*** data about children aged 0 af waves a-e (follow during 14
*** subsequent waves, and f-j (followed during 9 waves).
***
*****************************************************************


clear 




*cd "F:\Dropbox\jobs\post_e-stat\data\UKDA-5151-stata8\stata8\"
cd "C:\Work\Dropbox\jobs\post_e-stat"

*** Replace the above by the path to the BPHS folder 
*** on your  computer

set more off

***************************************************
*** Definition of a few local and temporary variables
***************************************************

*** Original BHPS waves identifiers 

local full "a b c d e f g h i j k l m n o p q r"

*** Numeric Wave indicators to be used with the pseudocohort files
local wa=0
local lgt=0
local cnt=3

*** Original BHPS waves ids ('Waves 1 / Age 0' of the  pseudo cohorts)
local coh="a b c d e f g h i j"




*** Use a local macro to store the names of the derived variables to be created at each wave

local dervar="isnsib isosib ispart ismum isdad nsibpres osibpres partpres mumpres dadpres orelpres"





*******************************************
*******************************************
*** Creating the 10 initial 'first wave' of the pseudocohorts 
*** Original BHPS waves A to J
*******************************************
*******************************************
***
*** We are setting up (child-level) first waves/Age 0 datasets for the 10 initial cohorts
*** We begin with the INDALL record (basic information about all household members) 
*** and keep only children aged under 1
***
*** We then merge it with the xEGOALT dataset in order to map the relationships of 
*** household members to the cohort children, using the xREL variable
***
*** The age of cohort children is recorded on the 1st of December each year. By doing so, we lose
*** A few children who had their first birthday between the time of interview and that date


foreach w in `coh' {

use "data\UKDA-5151-stata8\stata8/`w'indall.dta",clear

*** Value labels of the derived variables

label define lisnsib 0 "Not natural sibling" 1 "Natural sibling"
label define lisosib 0 "Not other sibling" 1 "Other sibling"
label define lispart 0 "Not mum/dad's partner" 1 "Mum/dad's partner"
label define lismum 0 "Not mother" 1 "Mother"
label define lisdad 0 "Not father" 1 "Father"
label define lisorel 0 "Not other rel." 1 "Other relative"


*** label define lnsibpres 0 "Nat. sibl. absent" 1 "Nat. sibl. present"
*** label define losibpres 0 "Other sibl. absent" 1 "Other sibl. present"
label define lpartpres 0 "mum/dad's part. abs." 1 "mum/dad's part. pres."
label define lmumpres 0 "Mother  absent" 1 "Mother present"
label define ldadpres 0 "Father absent" 1 "Father present"
*** label define lorelpres 0 "Other rel. absent" 1 "Other rel. pres"




keep if `w'age12==0

*** Indicator of whether obs refers to original cohort child
gen `w'iscohchi=1
label variable  `w'iscohchi "original cohort child"
label define l`w'iscohchi 1 "Cohort child at wave 1"
label values `w'iscohchi l`w'iscohchi 

*** Indicator of complete cases
gen miss=0
label variable miss "Whether missing at any wave"
label define lmiss 0 Present 1 Missing
label values miss lmiss


*** Merging with the xEGOALT data

merge 1:m pid using data\UKDA-5151-stata8\stata8/`w'egoalt,keepusing(`w'rel `w'osex ) gen(`w'_egoalt_init) 


*** Natural siblings are 'alter' identified as natural brother/sister of ego

gen `w'isnsib=0 
replace `w'isnsib=1 if `w'rel== 10 & `w'age12==0
label variable `w'isnsib "Whether is natural sibling"
label values `w'isnsib lisnsib 


*** Other siblings are 'alter' identified as other or half brother/sister of ego

gen `w'isosib=0 
replace `w'isosib=1 if `w'rel== 11 | `w'rel== 28 &`w'age12==0
label variable `w'isosib "Whether is other sibling of the cohort child"
label values `w'isosib lisosib


*** Same with step parent -- ie natural parent's partner
gen `w'ispart=0 
replace `w'ispart=1 if `w'rel== 25 &`w'age12==0
label variable `w'ispart "Whether is partner of mother/father  of the cohort child"
label values `w'ispart lispart


*** ... and with mothers and fathers
gen `w'ismum=0 
replace `w'ismum=1 if `w'rel== 13 & `w'osex==2 & `w'age12==0
label variable `w'ismum "Whether is mother of the cohort child"
label values `w'ismum lismum

gen `w'isdad=0 
replace `w'isdad=1 if `w'rel== 13 & `w'osex==1 & `w'age12==0
label variable `w'isdad "Whether is father of the cohort child"
label values `w'isdad lisdad


*** Same with other relative (ie other family + unrelated sharer)
gen `w'isorel=0
replace `w'isorel=1 if `w'rel>=15 & `w'rel<=25 
label variable `w'isorel "Whether is other relative of the cohort child"
label values `w'isorel lisorel

*** Creating child-level summary variables...
*** Since a child's households may change
foreach v in nsib osib part mum dad orel {

bysort pid: egen `w'`v'pres=total(`w'is`v'),missing
label variable `w'`v'pres "Number of `v' at wave `w'"
label values `w'`v'pres  l`v'pres 

ta `w'`v'pres
}



label variable `w'nsibpres "Number of natural siblings at wave `w'"
label variable `w'osibpres "Number of other siblings at wave `w'"
label variable `w'orelpres "Number of other relatives at wave `w'"
label variable `w'dadpres "Whether father was present at wave `w'"
label variable `w'mumpres "Whether mother was present at wave `w'"
label variable `w'partpres "Whether parent's partner was present at wave `w'"



*** Now we can safely drop all other observations ...

 keep if `w'iscohchi==1



*** Checking the results

ta `w'dadpres
ta `w'mumpres
ta `w'nsibpres
egen t=mean(`w'mumpres)
if t<.9 & t!=1 {
*???
}
drop t
drop `wrel' `w'osex 


sort pid

*** Saving the initial child level dataset, to be used later on

save data/`w'_tmp_init.dta,replace

}


*******************************************************
*******************************************************
*** Building the individual cohort datasets
*******************************************************
*******************************************************

foreach w in `coh' {


*** We begin with the household dataset at the each of the first wave of the
*** five component cohorts

*** the local macro w is the current bhps wave alphanumeric id

use data\UKDA-5151-stata8\stata8/`w'hhresp.dta,clear

*** We keep only households where children are likely to be present 
keep if `w'hhtyp==4 | `w'hhtyp==6 | `w'hhtyp==9



*** Merging the xHHSAMP dataset (survey design variables)

merge 1:1 `w'hid using data\UKDA-5151-stata8\stata8/`w'hhsamp.dta, keepusing(`w'psu `w'strata) gen(`w'_samp_merge)


*** Dropping respondents from booster samples (ie PSU unknown or >250)
drop if `w'psu<0 | `w'psu>250 


*** wa if the wave id number in the cohort datasets. It initial value is 0
local wa=`wa'+1

*** Variables list to be used in the programme
*** avar refers to household level variables
*** ivar are individual-level
*** This line should not be too long otherwise  Stata will skip the last variables names

local avar= "`w'nkids w`wa'_hmerge `w'agech `w'hhtype `w'region2 `w'ncouple `w'nonepar `w'pno `w'hgr2r `w'hgsex `w'hgspn `w'hgfno `w'hgmno `w'hgra `w'nchild `w'age `w'age12 `w'hoh `w'rach16 `w'sppid `w'fpid `w'mpid `w'hid `w'psu `w'strata `w'xewght" 
local ivar= "`w'nkids w`wa'_hmerge `w'agech `w'hhtype `w'region2 `w'ncouple `w'nonepar `w'pno `w'hgr2r `w'hgsex `w'hgspn `w'hgfno `w'hgmno `w'hgra `w'nchild `w'age `w'age12 `w'hoh `w'rach16 `w'sppid `w'fpid `w'mpid `w'hid `w'psu `w'strata `w'lewght `w'xewght `w'hhmem `w'newhy `w'nemnjn `w'depchl `w'movest `w'sampst `w'neyrjn4" 




sort `w'hid

*** Merging the 'Wave 1' child-level dataset previously saved
merge 1:m `w'hid using data/`w'_tmp_init.dta, gen(w`wa'_hmerge)


keep if w`wa'_hmerge==3
 gen w="`w'"


*** Only for BHPS Wave a (ie first component of the first pseudo cohort)
if w=="a" {
keep pid `avar' *pres  miss *is* w
}


else {
keep pid `ivar' *pres miss *is* w 
}




sort pid

*** Saving the temporary 'Wave' 1 dataset of a new cohort
*** with the individual, household level and survey design data

save data/tmp`w'_hhind.dta,replace



*** Length of the full range of BHPS waves for each one of the two
*** (final) appended cohorts datasets (ie with 5 original BHPS waves each)

local lfull=length("`full'")
gen lfull=`lfull'
replace lfull=lfull-`lgt'

*** If first cohort ( ie then 12 waves in addition to the first one
*** which means 12 letter + twelve spaces in the `full' macro define above 

if lfull>25 {
local lwv=25
}

*** If second cohort then 8 waves
else if lfull<=25 & lfull>15 {
local lwv=15
}




*** Macro allowing to identify current and next bhps waves
*** cnt indexes the letter number or the current wave
*** lag1 is all the remaining bhps waves to process for a given current cohort wave
*** lag2 is the current bhps wave id number
local lag1=substr("`full'",`cnt',`lwv') 
local lag2=substr("`full'",`cnt',1)
local llag1=length("`lag1'") 



*** Merging of the remaining waves (cohort 1)
*** And defining the relationship variables each time

if lfull>15 { 
local count=1

foreach mvar in `lag1' {
local oivar="`mvar'hid `mvar'pno `mvar'hgr2r `mvar'hgsex `mvar'hgspn `mvar'hgfno `mvar'hgmno `mvar'hgra `mvar'nchild `mvar'age `mvar'age12 `mvar'hoh `mvar'rach16 `mvar'sppid `mvar'fpid `mvar'mpid `mvar'hhmem `mvar'newhy `mvar'nemnjn `mvar'depchl `mvar'movest `mvar'sampst `mvar'neyrjn4 `mvar'lewght `mvar'xewght " 
local hvar= "`mvar'hid `mvar'agechy `mvar'hhtype  `mvar'ncouple `mvar'nonepar `mvar'nkids `mvar'region2"

 gen mvar="`mvar'"
 ta mvar 
 drop mvar

 

sort pid


ta `w'hhtype,m


gen `mvar'drop=0
label variable `mvar'drop "Whether dropped at bhps wave `mvar' "

*** Merge individual data from the *next* bhps wave
merge m:1 pid using data\UKDA-5151-stata8\stata8/`mvar'indall.dta,gen(imerge_`mvar') keepusing(`oivar')
sort `mvar'hid
*???stop
*** Overall attrition indicator
replace `mvar'drop=1 if imerge_`mvar'==1

*** Dropout indicator
replace miss=1 if imerge_`mvar'==1


*** Adding household level variables

merge m:1 `mvar'hid using data\UKDA-5151-stata8\stata8/`mvar'hhresp.dta,gen(hmerge_`mvar') keepusing(`hvar')

*** Not a good idea to drop people in another type of household at a subsequent wave
*** Since they precisely have moved out from a household with children
*** keep if `mvar'hhtype==4 | `mvar'hhtype==6 | `mvar'hhtype==9 

*** Dropping respondents who were not present at wave 1
drop if `w'iscohchi!=1




*** Adding sampling information

*** We use m:1 so that we keep the information about children who dropped out
*** at the next wave
 
merge m:1 `mvar'hid using data\UKDA-5151-stata8\stata8/`mvar'hhsamp.dta, keepusing(`mvar'psu `mvar'strata) gen(`mvar'_hsamp_merge) update

*** Dropping obs not present at wave 1
drop if `w'iscohchi!=1




*****************************************************************
*** Relationship module
*****************************************************************


*** Same as previously: merge data with xEGOALT records,
*** identify relationship between the cohort child and each household member
*** then create a child-level summary variable

merge m:m pid using data\UKDA-5151-stata8\stata8/`mvar'egoalt,keepusing(`mvar'rel `mvar'osex) gen (`w'egomerge_`mvar')

*** Dropping obs not present at wave 1
drop if `w'iscohchi!=1



*** Natural sibling are 'alter' identified as natural brother/sister of ego
*** the previous conditional statement (if egomeerge==3)
gen `mvar'isnsib=0 
replace `mvar'isnsib=1 if `mvar'rel== 10 & `mvar'age12!=0 
label values `w'isnsib l`w'isnsib 


*** Other siblings are 'alter' identified as other or half brother/sister of ego

gen `mvar'isosib=0 
replace `mvar'isosib=1 if (`mvar'rel== 11 | `mvar'rel== 28)
label values `w'isosib l`w'isosib

*** Same with step parent 
gen `mvar'ispart=0 
replace `mvar'ispart=1 if `mvar'rel== 25
label values `w'ispart l`w'ispart

*** ... and with mothers and fathers
gen `mvar'ismum=0 
replace `mvar'ismum=1 if `mvar'rel== 13 & `mvar'osex==2 
label values `w'isdad l`w'isdad

gen `mvar'isdad=0 

*** ??? if `w'egomerge_`mvar'==3
replace `mvar'isdad=1 if `mvar'rel== 13 & `mvar'osex==1 
label values `w'isdad l`w'isdad
*** Same with other relative (ie other family + unrelated sharer)
gen `mvar'isorel=0 
replace `mvar'isorel=1 if `mvar'rel>=15 & `mvar'rel<=25 
label values `w'isorel l`w'isorel

label variable `mvar'isnsib "Whether is natural sibling "
label variable `mvar'isosib "Whether is other sibling "
label variable `mvar'isorel "Whether is other relative "
label variable `mvar'isdad "Whether is father "
label variable `mvar'ismum "Whether is mother "
label variable `mvar'ispart "Whether is mum/dad's partner "



*** allocating the variables about relatives in the household to the cohort child
foreach v in nsib osib part mum dad orel {
bysort pid: egen `mvar'`v'pres=total(`mvar'is`v'),missing
label values `mvar'`v'pres l`v'pres 
}

*** Dropping households where more than one natural dad/mum is found
drop if (`mvar'dadpres>1 & `mvar'dadpres!=.) | (`mvar'mumpres>1 & `mvar'mumpres!=.)  



label variable `mvar'nsibpres "Number of natural siblings at wave `mvar'"
label variable `mvar'osibpres "Number of other siblings at wave `mvar'"
label variable `mvar'orelpres "Number of other relatives at wave `mvar'"
label variable `mvar'dadpres "Whether father was present at wave `mvar'"
label variable `mvar'mumpres "Whether mother was present at wave `mvar'"
label variable `mvar'partpres "Whether parent's partner was present at wave `mvar'"



*** Retaining one obs per child
*** It does not matter at this stage whether this is the original one
bysort pid:gen n=_n
keep if n==1
drop n



sort pid


*** Dropping respondents who entered the sample at a later stage

*** keep if `mvar'psu !=-9 & `mvar'psu<300


drop w
gen w="`w'" 
local count=`count'+1
gen count=`count'
ta count 
drop count
}

}



local favar= "nkids agechy hid hhtype ncouple nonepar pno hgr2r region2 hgsex hgspn hgfno hgmno hgra age age12 nchild hoh rach16 sppid fpid mpid psu strata" 
local fivar= "nkids agechy hid hhtype ncouple nonepar pno hgr2r region2 hgsex hgspn hgfno hgmno hgra age age12 nchild hoh rach16 sppid fpid mpid psu strata hhmem newhy nemnjn depchl movest sampst neyrjn4 lewght xewght" 



*** Changing original BHPS variable names (with waves identified by a letter)
*** to cohort variable names with wave number at the end 
*** Below is for the first 'age 0' wave only ...

if w=="a" {


foreach var in `favar' `dervar' {
rename `w'`var' `var'1
}


}

else   {


foreach var in `fivar' `dervar' {
rename `w'`var' `var'1
}



}

*** ... Then for all the remaining waves
 
 gen lag1="`lag1'"
 ta lag1


local inc=2
forval ad = 1(2) `llag1' {
 gen ad=`ad'
 ta ad
 drop ad

local wv =substr(lag1,`ad',1)
 gen wv="`wv'"
 ta wv
 drop wv

foreach var in `fivar' `dervar' {
replace `wv'`var'=. if `wv'drop==1
rename `wv'`var' `var'`inc'
}

local inc=`inc'+1

}

*** clearing up

 drop  *rel *osex 
bysort pid: gen c=_n
keep if c==1 & `w'iscohch==1


*** Saving the full component cohort starting at bhps wave w
save data/tmp_`w'_coh.dta,replace


*** Moving to the subsequent current and next waves

local lgt=`lgt'+2





local cnt=`cnt'+2
}


*** Now we can create the actual pseudocohorts



use data/tmp_a_coh.dta,clear

foreach w in b c d e {
quietly append using data/tmp_`w'_coh.dta
}

*** The wave dropout indicator is specific to a given component cohort 
*** and therefore has missing values among observation of other cohorts
*** We rectify this by recoding missing as present (0)

foreach w in b c d e f g h i j k l m n o p q r {
replace `w'drop=0 if `w'drop==.
}

*** Full attrition pattern
egen attpat=group(*drop),missing label
label variable attpat "Attrition pattern (0 Present 1 Missing)"


*** Number of waves missed
egen numdrop=rowtotal(*drop),missing 
label variable numdrop "Number of waves missed"

drop *distmov  w 

*** Additional cleanup: children coded as lodger and grandparent
drop if hgr2r1==23 | hgr2r2==23 | hgr2r2==16


*** Dropping children with the same hid at last wave and also cases with same pids

bysort hid14:gen n=_N
ta n

***
drop if n>1  & n<30
drop n
bysort pid: gen n=_N
drop if n!=1
drop n

save data/estat_bhps_cohae.dta,replace

use data/tmp_f_coh.dta,clear

foreach w in g h i j {
quietly  append using data/tmp_`w'_coh.dta
}

foreach w in g h i j k l m n o p q r {
replace `w'drop=0 if `w'drop==.
}

egen attpat=group(*drop),missing label
label variable attpat "Attrition pattern (0 Present 1 Missing)"

egen numdrop=rowtotal(*drop),missing 
label variable numdrop "Number of waves missed"



*** Same as above
drop if hgr2r1==23


drop *distmov w 
bysort hid9:gen n=_N
ta n
drop if n>1 & n<100
drop n
bysort pid: gen n=_N
drop if n!=1
drop n

save data/estat_bhps_cohfj.dta,replace






***********************************************
*** Descriptives
***********************************************

*** Descriptive are essentially the same for each cohort,
*** so we will automate them
clear
set more off



foreach coh in ae fj {


use "data\estat_bhps_coh`coh'.dta",clear

label define lpfam 0 "Not LP family" 1 "Lone parent family"
label define lchg 0 "No change" 1 "At least 1 change"



*** Cross-sectional tables are computed  at waves 1, 9 and 14 (1st cohort)
*** And waves 1 and 9 (2nd cohort)
*** However, longitudinal indicators are computed using all waves available (14 or 9)
*** As a result, in order to have intermediary longitudinal indicators computed
*** the value of lst below needs to be changed accordingly

local lst=14
local mid=9
gen cnt=2
gen coh="`coh'"

if coh=="ae" {
foreach drop in b c d e f g h i j k l m n o p q r  {
local num=cnt
rename `drop'drop drop`num'
replace cnt=cnt+1
}
}


if coh=="fj" {

foreach drop in g h i j k l m n o p q r {
local num=cnt
rename `drop'drop drop`num'
replace cnt=cnt+1
}


local lst=9
local mid=""
}

gen drop1=0

  
label define lnr 0 None 1 1 2 2 3 "3+"
forval wv = 1/`lst' {




*** Note: we are using Government office regions rather than strata ids
*** for inferences: the small number of obs cause some of the strata to 
*** have only one PSU

*** Missing values for the region variable cause problems
*** when setting up complex survey command svyset
*** Therefore, we should recode them as system missing


recode region2`wv' (-9=.), gen (nregion2`wv')

*** Recoding dichotomic indicator of mum/dad presence and number of
*** siblings, stepsiblings, step parents and other relatives
*** at each wave



label variable nsibpres`wv' "Number of natural sibling present at wave `wv'"
label variable orelpres`wv' "Number of natural sibling present at wave `wv'"
label variable osibpres`wv' "Number of natural sibling present at wave `wv'"

label variable mumpres`wv' "Whether mother sibling is present at wave `wv'"
label variable dadpres`wv' "Whether father is present at wave `wv'"
label variable partpres`wv' "Whether a parent's partner is present at wave `wv'"



label values partpres`wv' lpartpres 
label values mumpres`wv' lmumpres 
label values dadpres`wv' ldadpres 

gen lpfam`wv'=0 if dadpres`wv'==1 & mumpres`wv'==1 
replace lpfam`wv'=1 if dadpres`wv'==0 | mumpres`wv'==0 
label variable lpfam`wv' "Whether a lone parent family"
label values lpfam`wv' lpfam

}



label define lfamtyp 1 "2 N parents 1c" 2 "2 N parents 2+c" 3 "1 L parents " 4 "1 NP 1 part"
label define l2famtyp 0 "Two parents" 1 "Lone parent"

*** Number of natural parents and type of family at waves 1 & 14
foreach wv of numlist 1/`lst' {

gen n3nrpar`wv'=dadpres`wv'+mumpres`wv' 
label variable n3nrpar`wv' "Number of natural parents in the household at wave `wv'"


gen famtyp`wv'=5 
quietly replace famtyp`wv'=1 if dadpres`wv'==1 & mumpres`wv'==1 & nsibpres`wv'==0
quietly replace famtyp`wv'=2 if dadpres`wv'==1 & mumpres`wv'==1 & nsibpres`wv'>0 & nsibpres`wv'<20
quietly replace famtyp`wv'=3 if (dadpres`wv'==0 | mumpres`wv'==0) & partpres`wv'==0 
quietly replace famtyp`wv'=4 if (dadpres`wv'==0 | mumpres`wv'==0) & partpres`wv'==1
replace famtyp`wv'=. if dadpres`wv'==.
quietly ta famtyp`wv'
quietly label values famtyp`wv' lfamtyp



recode famtyp`wv' (1/2=0) (2/4=1) , gen (n2famtyp`wv')
quietly label values n2famtyp`wv' l2famtyp

label variable famtyp`wv' "Family type at wave `wv' -- 4 categories"
label variable n2famtyp`wv' "Family type at wave `wv' -- 2 categories"


quietly svyset psu`wv' [pw=xewght`wv'],strata(nregion2`wv')
tabout n3nrpar1 using "bhps_`coh'_jan13.csv",replace cells(col ci ) svy style(csv) ptotal(none)

svyset psu`lst' ,strata(nregion2`lst')
tabout n3nrpar1 using "bhps_`coh'_uwg_jan13.csv",svy percent replace cells(col ci ) style(csv) ptotal(none)

}


*** Number of each family type at waves 1, 9, 14
foreach var in n3nrpar nsibpres osibpres orelpres famtyp {
foreach wv of numlist 1 `mid' `lst' {
quietly svyset psu`wv' [pw=xewght`wv'],strata(nregion2`wv')
svy:ta `var'`wv' ,  percent format(%9.1f) ci nomarg

tabout `var'`wv' using "bhps_`coh'_jan13.csv" ,percent append cells(col ci ) svy style(csv) ptotal(none)

svyset psu`lst' ,strata(nregion2`lst')

tabout `var'`wv' using "bhps_`coh'_uwg_jan13.csv" ,percent append cells(col ci )  svy style(csv) ptotal(none)
}

}

*** Indicators of whether a member of the household left at some point
*** Note: in the case of siblings, this can also signal an older brother/sister
*** who goes to live in a hall of residence or with a partner, etc.
*** By changing the threshold value of numdrop in the conditional statements below
*** cases with missing obs at some waves can be used in the indicators

foreach var in mum dad orel nsib osib part {

forval w=2/`lst' {
local wl=`w'-1
gen `var'lft`w'=0 if numdrop<1 
replace `var'lft`w'=1 if `var'pres`w'<`var'pres`wl'  & `var'pres`wl'!=. 
*** gen wl=`wl'
label variable `var'lft`w' "Whether `var' left between waves `wl' and `w'" 
gen a`var'lft`w'=.
replace a`var'lft`w'=age12`wl' if `var'lft`w'==1 & numdrop<1 
label variable a`var'lft`w' "Age when `var' left between waves `wl' and `w'" 
}

egen t`var'lft=rowtotal(`var'lft*) if numdrop<1 
label variable t`var'lft "Number of time `var' left the household"

egen a`var'lft=rowtotal(a`var'lft*) if t`var'lft!=0 & numdrop<1  , missing
egen a2`var'lft=rowmin(a`var'lft*) if numdrop<1 
replace a`var'lft=a2`var'lft if t`var'lft==2

replace a`var'lft=-2 if a`var'lft==.
replace a`var'lft=-1 if `var'pres1==0
label variable a`var'lft "Age when `var' left the household"

}


label define ladadlft -2 "Did not leave" -1 "Absent at birth"  

if coh=="ae" {
recode adadlft  (1/3=1) (4/6=2) (7/9=3) (10/12=4) (13/20=5) , gen(n5adadlft)
label define l5adadlft -2 "Did not leave" -1 "Absent at birth"  0 "Under 1" 1 "1-3" 2 "4-6" 3 "7-9" 4 "10-12" 5 "13-16"
label variable n5adadlft "Age when father left -- 6 categories"

drop coh
}

else {
recode adadlft  (1/3=1) (4/6=2) (7/12=3) if numdrop<1 , gen(n5adadlft)
label define l5adadlft -2 "Did not leave" -1 "Absent at birth"  0 "Under 1" 1 "1-3" 2 "4-6" 3 "7-12" 
label variable n5adadlft "Age when father left -- 6 categories"
drop coh
}

*** Age at which father left 
label values n5adadlft l5adadlft
label values adadlft ladadlft

svyset psu`lst' [pw=lewght`lst'],strata(nregion2`lst')
svy:ta n5adadlft ,percent format(%9.1f) ci
svy:ta adadlft ,percent format(%9.1f) ci

svyset psu`lst' ,strata(nregion2`lst')
svy:ta n5adadlft ,percent format(%9.1f) ci
svy:ta adadlft ,percent format(%9.1f) ci





*** Number of changes in family type

gen cfamtyp`w'=0 if  numdrop<1 
forval w=2/`lst' {
local wl=`w'-1
replace cfamtyp=cfamtyp+1 if n2famtyp`w'!=n2famtyp`wl' & n2famtyp`wl'!=. & numdrop<1 
}
recode cfamtyp(2/7=2), gen (chfamtyp)
label variable cfamtyp "Number of change in family type (2 vs one parent)"
label variable chfamtyp "Number of change in family type (2 vs one parent) -- 3 categories"
label define lchfamtyp 2 "2+"
label values chfamtyp lchfamtyp

svyset psu`lst' [pw=lewght`lst'],strata(nregion2`lst')
svy:ta chfamtyp,percent format(%9.1f) ci


tabout chfamtyp using "bhps_`coh'_jan13.csv",percent append cells(col ci ) svy style(csv) ptotal(none)

svyset psu`lst' ,strata(nregion2`lst')
tabout chfamtyp  using "bhps_`coh'_uwg_jan13.csv",percent append cells(col ci ) svy style(csv) ptotal(none)



*** Whether a change in the number of natural siblings
*** Other relatives, step/half siblings, step parent
*** happened at any wave

foreach var in orel nsib osib part {
gen n2`var'chg=0 if numdrop<1

forval w=2/`lst' {
local wl=`w'-1
replace n2`var'chg=1 if (`var'pres`w'!=`var'pres`wl' & `var'pres`wl'!=. ) & numdrop<1 
label values n2`var'chg lchg
}

svy:ta n2`var'chg ,percent format(%9.1f) ci

tabout n2`var'chg  using "bhps_`coh'_jan13.csv",percent append cells(col ci ) svy style(csv) ptotal(none)

svyset psu`lst' ,strata(nregion2`lst')
tabout n2`var'chg   using "bhps_`coh'_uwg_jan13.csv",percent append cells(col ci ) svy style(csv) ptotal(none)

}


label variable n2nsibchg "Whether a change in natural siblings occured"
label variable n2osibchg "Whether a change in half/step siblings occured"
label variable n2orelchg "Whether a change in other relative occured"
label variable n2partchg "Whether a change in step parent occured"


drop *merge*
save "data\estat_bhps_coh`coh'_fin.dta",replace

}




****************
*** Creating and saving the e-stat dataset
*** which can be merged back with any BHPS file
*** using PID
****************



clear
set more off

foreach coh in ae fj {


use data\estat_bhps_coh`coh'_fin.dta


keep 	*pres* *lft* *chg *famtyp* pid hid* n3* *wght* *cohc* psu* nregion* *miss* *drop* *miss* attpat
rename adadlft agdadlft



	sort pid
	compress
 save data\estat_bhps_cohort_`coh'_v7,replace

}


**** Erasing temporary files

local datafiles: dir "data/" files "*tmp*.dta"

foreach datafile of local datafiles {
        rm data/`datafile'
}





